'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _fsExtra = require('fs-extra');

var _fsExtra2 = _interopRequireDefault(_fsExtra);

var _path = require('path');

var _path2 = _interopRequireDefault(_path);

var _constants = require('../constants');

var _spawnHelper = require('../utils/spawnHelper');

var _execHelper = require('../utils/execHelper');

var _execHelper2 = _interopRequireDefault(_execHelper);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var IS_WINDOWS = process.platform === 'win32';
var ticks = IS_WINDOWS ? '"' : '\'';

var parseSize = function parseSize(ptr) {
  var idx = ptr.indexOf('size ') + 5;
  return Number(ptr.substring(idx).trim());
};

exports.default = function (crednetialsCallback) {
  var clean = function clean(to, from, source) {
    var workdir = source.repo().workdir();
    var filePath = _path2.default.join(workdir, source.path());
    var command = 'git lfs clean ' + ticks + source.path() + ticks;

    return _fsExtra2.default.readFile(filePath).then(function (buf) {
      return (0, _execHelper2.default)(command, buf, { cwd: workdir });
    }).then(function (_ref) {
      var stdout = _ref.stdout;

      var sha = new Buffer(stdout);
      return to.set(sha, sha.length).then(function () {
        return _constants.Error.CODE.OK;
      });
    });
  };

  var smudge = function smudge(to, from, source) {
    var workdir = source.repo().workdir();
    var parts = source.path().split('/');
    var filepath = parts[parts.length - 1];
    var ptr = from.ptr();
    var size = parseSize(ptr);
    var echo = IS_WINDOWS ? 'echo|set /p="' + ptr + '"' : 'echo -ne "' + ptr + '"';

    var promise = IS_WINDOWS ? (0, _spawnHelper.winSpawn)('git lfs smudge ' + ticks + filepath + ticks, ptr, { cwd: workdir }) : (0, _spawnHelper.spawnShell)(echo + ' | git lfs smudge ' + ticks + filepath + ticks, { cwd: workdir }, size, crednetialsCallback);

    return promise.then(function (_ref2) {
      var stdout = _ref2.stdout;
      return to.set(stdout, stdout.length).then(function () {
        return _constants.Error.CODE.OK;
      });
    });
  };

  var previousFilterPromise = Promise.resolve();

  return function (to, from, source) {
    var mode = source.mode();

    var runNextFilter = function runNextFilter() {
      return Promise.resolve().then(function () {
        if (mode === 1) {
          return clean(to, from, source);
        }
        return smudge(to, from, source);
      }).then(function () {
        return _constants.Error.CODE.OK;
      }, function () {
        return _constants.Error.CODE.PASSTHROUGH;
      });
    };

    previousFilterPromise = previousFilterPromise.then(runNextFilter, runNextFilter);

    return previousFilterPromise;
  };
};