'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _ramda = require('ramda');

var _ramda2 = _interopRequireDefault(_ramda);

var _lfsCommands = require('./lfsCommands');

var _constants = require('../constants');

var _generateResponse = require('../utils/generateResponse');

var _generateResponse2 = _interopRequireDefault(_generateResponse);

var _helpers = require('../helpers');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var isValidLine = function isValidLine(str) {
  return str !== '';
};

var generateCheckoutStats = function generateCheckoutStats(raw) {
  if (raw && typeof raw === 'string') {
    var stats = {};
    var outputLines = raw.split('Git LFS:');
    var filteredLines = _ramda2.default.filter(isValidLine, outputLines);
    var statLine = filteredLines.pop();

    var byteResults = (0, _helpers.regexResult)(statLine, _constants.regex.TOTAL_BYTES);

    stats.total_bytes_checked_out = byteResults !== null ? byteResults[0].trim() : _constants.BAD_REGEX_PARSE_RESULT;

    stats.total_bytes = byteResults !== null ? byteResults[1].trim() : _constants.BAD_REGEX_PARSE_RESULT;

    var fileResults = (0, _helpers.regexResult)(statLine, _constants.regex.TOTAL_FILES);

    stats.total_files_checked_out = fileResults !== null ? fileResults[0].trim() : _constants.BAD_REGEX_PARSE_RESULT;

    var skippedByteResults = (0, _helpers.regexResult)(statLine, _constants.regex.SKIPPED_BYTES);

    stats.total_bytes_skipped = skippedByteResults !== null ? skippedByteResults[0].trim() : _constants.BAD_REGEX_PARSE_RESULT;

    var skippedFileResults = (0, _helpers.regexResult)(statLine, _constants.regex.SKIPPED_FILES);

    stats.total_files_skipped = skippedFileResults !== null ? skippedFileResults[0].trim() : _constants.BAD_REGEX_PARSE_RESULT;

    (0, _helpers.verifyOutput)(stats, raw);

    if (statLine.includes('error:')) {
      stats.checkout_error = statLine.split('error:')[1].trim();
    }

    return stats;
  }
  return {};
};

function checkout(repo, callback) {
  var response = (0, _generateResponse2.default)();
  var repoPath = repo.workdir();

  return _lfsCommands.core.checkout('', { cwd: repoPath }, callback).then(function (_ref) {
    var stdout = _ref.stdout;

    response.raw = stdout;
    response.checkout = generateCheckoutStats(stdout);

    if (response.checkout.checkout_error) {
      response.success = false;
      response.stderr = response.checkout.checkout_error;
      response.errno = _constants.BAD_CORE_RESPONSE;
    }

    return response;
  }, (0, _helpers.errorCatchHandler)(response));
}

exports.default = checkout;